==> haskell-sandwich-0.1.5.2-74-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-1OqmkGHuJYVirx7WeHdBg
key:                  sandwich-0.1.5.2-1OqmkGHuJYVirx7WeHdBg
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  1e562f7bf6b5030eb9e4376f65f11a0e
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-1OqmkGHuJYVirx7WeHdBg
depends:
    aeson-2.1.2.1-PtSa2Du7ZnC9cVeQoj7Qs
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1
    brick-1.9-3Ac5tHF1xZjGgmyu77mvjG bytestring-0.11.5.3
    colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-J6aQ9lxqrpq31IW12djLAd
    haskell-src-exts-1.23.1-F0Qm1DIDZvYLUNcxB9eu4d
    lifted-async-0.10.2.7-KNU6kxHoCLs4MZf8THuCEV
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    monad-control-1.0.3.1-Gw3XM64JSJ5ntrqlz8Emw
    monad-logger-0.3.42-FIB4S4nvnoBKOGKqiukiqY mtl-2.2.2
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD process-1.6.18.0
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    safe-exceptions-0.1.7.4-3Z5aHvleGFbLTLwdzNM383 stm-2.5.1.0
    string-interpolate-0.3.4.0-3CabGefDNZoJK54ZtlwMbF
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    vty-5.39-I9c2R2KPeDU9JipCyr2Puc

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.1.5.2-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.1.5.2
visibility:           public
id:                   sandwich-0.1.5.2-9Fn9KDmCB1Z9eCkLd7WLuj
key:                  sandwich-0.1.5.2-9Fn9KDmCB1Z9eCkLd7WLuj
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  612c548fb3b6b4baab7e34ed65d732df
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util Test.Sandwich.Golden.Update
    Test.Sandwich.Internal.Formatters Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.1.5.2-9Fn9KDmCB1Z9eCkLd7WLuj
depends:
    aeson-2.1.2.1-DotSWK7wQi51TFnSZ5tWn0
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1
    brick-1.9-3Ac5tHF1xZjGgmyu77mvjG bytestring-0.11.5.3
    colour-2.3.6-9rTtk69Pc3k5Ik3SUsZeCb containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-7vLyOa9fkZ298St81EfwyJ
    haskell-src-exts-1.23.1-F0Qm1DIDZvYLUNcxB9eu4d
    lifted-async-0.10.2.7-KNU6kxHoCLs4MZf8THuCEV
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    monad-control-1.0.3.1-Gw3XM64JSJ5ntrqlz8Emw
    monad-logger-0.3.42-Fplowaaw5dGGc6Iy2AGkJk mtl-2.2.2
    optparse-applicative-0.17.1.0-4tPjpOfYmOi9nj8To0UB1j
    pretty-show-1.10-Il8DKxKkDEW3pjtvdJ1ynD process-1.6.18.0
    safe-0.3.21-D0Qa6qmXFrgLhocJR17U7j
    safe-exceptions-0.1.7.4-3Z5aHvleGFbLTLwdzNM383 stm-2.5.1.0
    string-interpolate-0.3.4.0-62xKYbV2sJnJqLQgliOVrx
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    vty-5.39-I9c2R2KPeDU9JipCyr2Puc

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
